LanguageAvailability

Struct LanguageAvailability 

pub struct LanguageAvailability { /* private fields */ }
Wraps Translation.framework’s LanguageAvailability.

Implementations

Source

impl LanguageAvailability

pub fn new() -> Result<Self, TranslationError>

Creates a new LanguageAvailability wrapper.

pub fn with_preferred_strategy( preferred_strategy: TranslationStrategy, ) -> Result<Self, TranslationError>

Creates a LanguageAvailability wrapper with a preferred strategy.

pub fn preferred_strategy( &self, ) -> Result<TranslationStrategy, TranslationError>

Returns Translation.framework’s preferred strategy for this availability probe.

pub fn supported_languages(&self) -> Result<Vec<String>, TranslationError>

Returns supported language identifiers from LanguageAvailability.supportedLanguages.

pub fn supported_language_objects( &self, ) -> Result<Vec<Language>, TranslationError>

Returns supported language objects from LanguageAvailability.supportedLanguages.

pub fn status_for_pair( &self, source_language: &str, target_language: &str, ) -> Result<LanguageAvailabilityStatus, TranslationError>

Returns pair availability for explicit source and target identifiers.

pub fn status_for_language_pair( &self, pair: &LanguagePair, ) -> Result<LanguageAvailabilityStatus, TranslationError>

Returns pair availability for a LanguagePair.

pub fn status_for_languages( &self, source_language: &Language, target_language: Option<&Language>, ) -> Result<LanguageAvailabilityStatus, TranslationError>

Returns pair availability using LanguageAvailability.status(from:to:).

pub fn status_for_text( &self, text: &str, target_language: &str, ) -> Result<LanguageAvailabilityStatus, TranslationError>

Returns translation availability for text and a target identifier.

pub fn status_for_text_in_language( &self, text: &str, target_language: Option<&Language>, ) -> Result<LanguageAvailabilityStatus, TranslationError>

Returns translation availability for text with an optional target language.