pub struct TranslationSessionConfiguration { /* private fields */ }Expand description
Serializable mirror of TranslationSession.Configuration from Translation.framework.
Implementations
Sourceimpl TranslationSessionConfiguration
impl TranslationSessionConfiguration
Sourcepub fn new(source: impl Into<String>, target: impl Into<String>) -> Self
pub fn new(source: impl Into<String>, target: impl Into<String>) -> Self
Creates a session configuration from explicit source and target identifiers.
Sourcepub fn with_optional_target(
source: impl Into<String>,
target: Option<String>,
) -> Self
pub fn with_optional_target( source: impl Into<String>, target: Option<String>, ) -> Self
Creates a session configuration with an optional target identifier.
Sourcepub fn from_language_pair(pair: impl Into<LanguagePair>) -> Self
pub fn from_language_pair(pair: impl Into<LanguagePair>) -> Self
Creates a session configuration from a LanguagePair.
Sourcepub fn try_from_translation_configuration(
configuration: &TranslationConfiguration,
) -> Result<Self, TranslationError>
pub fn try_from_translation_configuration( configuration: &TranslationConfiguration, ) -> Result<Self, TranslationError>
Converts a TranslationConfiguration into a session configuration.
Sourcepub fn target(&self) -> &str
pub fn target(&self) -> &str
Returns the target identifier or an empty string when unspecified.
Sourcepub fn optional_target(&self) -> Option<&str>
pub fn optional_target(&self) -> Option<&str>
Returns the optional target language identifier.
Sourcepub const fn preferred_strategy(&self) -> TranslationStrategy
pub const fn preferred_strategy(&self) -> TranslationStrategy
Returns the preferred Translation.framework strategy.
Sourcepub fn with_preferred_strategy(
self,
preferred_strategy: TranslationStrategy,
) -> Self
pub fn with_preferred_strategy( self, preferred_strategy: TranslationStrategy, ) -> Self
Returns a copy with the given preferred strategy.
Sourcepub fn language_pair(&self) -> LanguagePair
pub fn language_pair(&self) -> LanguagePair
Returns this configuration as a LanguagePair.